package com.jwk.spring.boot.rfid;

import com.jwk.spring.boot.autoconfigure.Properties;
import com.mot.rfid.api3.RFIDReader;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

import java.util.concurrent.Executors;


/**
 * @author JWK
 * @version 1.0
 * @date 2022/9/7 17:00
 */
@Slf4j
@Data
public class RfidReaderClient {

    private RFIDReader reader = null;
    private RfidReaderUtil rfidReaderUtil = null;
    private Properties.SubProperties properties;

    /**
     * 初始化
     *
     * @param properties
     */
    public RfidReaderClient(Properties.SubProperties properties) {
        this.properties = properties;
    }

    /**
     * 打开串口 异步
     */
    public void connectAsync() {
        Executors.newSingleThreadExecutor().execute(() -> this.connect());
    }

    /**
     * 连接
     */
    public void connect() {
        for (; ; ) {
            try {
                reader = new RFIDReader(properties.getHost(), properties.getPort()
                        , properties.getTimeoutMilliseconds());
                reader.connect();
                rfidReaderUtil = new RfidReaderUtil(reader, properties);
                log.info("RfidReader：{}:{},连接成功！", properties.getHost(), properties.getPort());
                break;
            } catch (Exception e) {
                log.error("RfidReader：{}:{},连接失败！", properties.getHost(), properties.getPort(), e);
                try {
                    Thread.sleep(3000);
                } catch (InterruptedException ee) {
                    ee.printStackTrace();
                }
            }
        }
    }
}
