package com.jwk.spring.boot.rfid;

import com.jwk.spring.boot.autoconfigure.Properties;
import com.mot.rfid.api3.InvalidUsageException;
import com.mot.rfid.api3.OperationFailureException;
import com.mot.rfid.api3.RFIDReader;
import com.mot.rfid.api3.TagData;
import lombok.extern.slf4j.Slf4j;

/**
 * @author JWK
 * @version 1.0
 * @date 2022/12/12 22:10
 */
@Slf4j
public class RfidReaderUtil {

    private RFIDReader reader;
    private Properties.SubProperties properties;

    public RfidReaderUtil(RFIDReader reader, Properties.SubProperties properties) {
        this.reader = reader;
        this.properties = properties;
    }

    /**
     * 读取标签
     *
     * @return
     * @throws Exception
     */
    public TagData[] readTags() {
        TagData[] readTags = null;
        try {
            if (!reader.isConnected()) {
                throw new Exception("连接已经断开！");
            }

            // 清空标签
            reader.Actions.purgeTags();

            reader.Actions.Inventory.perform();

            Thread.sleep(1000);

            reader.Actions.Inventory.stop();

            readTags = reader.Actions.getReadTags(properties.getNumberOfTags());
        } catch (Exception e) {
            log.error("RfidReader读取异常!", e);
            reader = new RFIDReader(properties.getHost(), properties.getPort(), properties.getTimeoutMilliseconds());
            try {
                reader.connect();
            } catch (InvalidUsageException ex) {
                ex.printStackTrace();
            } catch (OperationFailureException ex) {
                ex.printStackTrace();
            }
        }
        return readTags;
    }
}
